@@ -162,7 +162,7 @@ forestplot.default <- function(labeltext,
        boxsize = boxsize,
        is.summary = is.summary,
        shapes_gp = shapes_gp,
-       hrzl_lines = hrzl_lines,
+       lines = list(horizontal = hrzl_lines),
        line.margin = line.margin,
        fn.legend = fn.legend,
        fn.ci_sum = fn.ci_sum,
